#!/bin/bash
#
#

# Function to check if the osd pods are ready or not
osd_pods_ready() {
  pod_list=$(kubectl -n rook-ceph get pods -l app=rook-ceph-osd -o 'jsonpath={..status.conditions[?(@.type=="Ready")].status}' | tr " " "\n")

  osdPodsReady=true;

  if [ "${pod_list}" = '' ];
  then
        osdPodsReady=false;
        return;
  fi

  for podStatus in $pod_list
  do
      if [ $podStatus != "True" ];
      then
            osdPodsReady=false
      fi
  done

}

#Check if the pvc is Bound
pvc_bound() {
  pvcClaimStatus=$(kubectl get pvc -o=jsonpath="{.items[*].status.phase}")
  
  pvcClaimBound=true;
  
  if [ $pvcClaimStatus != "Bound" ]
  then
    pvcClaimBound=false;
  fi
}


echo "[INFO]: Started rook-ceph installation"
cd ../rook-ceph-installer
kubectl create -f common.yaml

kubectl create -n rook-ceph clusterrolebinding rook-ceph-system-admin --clusterrole=cluster-admin --serviceaccount=rook-ceph:rook-ceph-system

kubectl create -f operator.yaml

kubectl create -f cluster-test.yaml

#Check if the osd pods are ready now
osd_pods_ready;

counter=1

while [ $osdPodsReady != true ];
do

    if [ "${counter}" -gt 20 ];
    then
      echo "Ceph installation didn't succeed in 600s. Exiting !!!"
      exit 1
    fi

    osd_pods_ready;
    echo "rook-ceph-osd pods not ready yet. Waiting for pods.." && sleep 30;    
    counter=$((counter+1))
  
done


kubectl create -f object.yaml

kubectl create -f object-storage-class.yaml

kubectl create -f block-storage.yaml

kubectl create -f block-storage-class.yaml

kubectl patch storageclass default -p '{"metadata": {"annotations":{"storageclass.kubernetes.io/is-default-class":"true"}}}'

#Block storage verification
kubectl create -f mysql.yaml

#Check if pvc is bound
pvc_bound;

while [ $pvcClaimBound != true ];
do
    pvc_bound;
    echo "Waiting for PVC to be bound." && sleep 10;
done

#Object store verification
# To confirm the object store is configured, wait for the rgw pod to start
#kubectl -n rook-ceph get pod -l app=rook-ceph-rgw


#Delete PVC
kubectl delete -f mysql.yaml

cd ../scripts
echo "Ceph installation completed successfully"