#!/bin/bash

# Validate if last command executed successfully
# $1- Error message
function validate_exec() {
  if [ $? -ne 0 ]; then
    echo "$1 !!!!!"
    exit 1
  fi
}

# Validate response against null check
# $1 - variables
# $2 - object name
function validateNullCheck() {
  if [ -z "$1" ]; then
    echo "[ERROR]: $2 is null ... Exiting"
    exit 1
  fi
}

# Total steps
total_steps=4

# Current step
current_step=1

if [ "${GPU_DRIVER_INSTALLED}" == true ]; then
  total_steps=$((total_steps + 1))
fi

echo "<----------- Total steps: ${total_steps} Current step: ${current_step}  Estimated time: 2s ----------->"
. /etc/os-release
export OS_PLATFORM=ubuntu
if [ "${NAME}" == "Red Hat Enterprise Linux Server" ]; then
  export OS_PLATFORM=rhel
elif [ "${NAME}" == "CentOS Linux" ]; then
  export OS_PLATFORM=centos
fi

echo $OS_PLATFORM

if [[ "${OS_PLATFORM}" == "ubuntu" ]]; then
  sudo apt-get install -y jq
else
  readonly epelInstallUrl=https://dl.fedoraproject.org/pub/epel/epel-release-latest-7.noarch.rpm
  sudo yum -y install $epelInstallUrl
  sudo yum -y install jq
fi

echo "<----------- Total steps: ${total_steps} Current step: ${current_step}  Estimated time: 2s ----------->"
cd ../common/scripts

if [[ "${IS_AIRGAP}" == "true" ]]; then
  export CW=$(pwd)
  cd $INFRA_FOLDER
  sudo ./setup.sh
  cd $CW
else
  curl -sSL https://k8s.kurl.sh/ai-fabric-21-4-production | sudo bash
  validate_exec "[ERROR]: Failed to execute infra installer. Exiting !!!"
fi

current_step=$((current_step + 1))

echo "<----------- Total steps: ${total_steps} Current step: ${current_step}  Estimated time: 2s ----------->"
sudo chmod +r /etc/kubernetes/admin.conf
export KUBECONFIG=/etc/kubernetes/admin.conf
current_step=$((current_step + 1))

if [ "${GPU_DRIVER_INSTALLED}" == true ]; then
  echo "<----------- Total steps: ${total_steps} Current step: ${current_step}  Estimated time: 2s ----------->"
  bash attach_gpu_drivers.sh
  validate_exec "[ERROR]: Failed to attach GPU drivers. Exiting !!!"
  current_step=$((current_step + 1))
fi

echo "<----------- Total steps: ${total_steps} Current step: ${current_step}  Estimated time: 2s ----------->"

#Fetch Rook Version
toolbox_pod=$(kubectl -n rook-ceph get pod -l app=rook-ceph-tools -o jsonpath="{.items[0].metadata.name}")
validate_exec "[ERROR]: Failed to get rook ceph tool name. Exiting !!!"

rook_version=$(kubectl -n rook-ceph exec -it $toolbox_pod -- sh -c 'rook version | cut -d ':' -f2')
validate_exec "[ERROR]: Failed to get rook ceph version. Exiting !!!"

echo "rook-ceph version: $rook_version"

#https://github.com/rook/rook/pull/6437 this is fixed in 1.4.6
if [[ "${rook_version}" == *"1.4.3"* ]]; then
  # https://github.com/rook/rook/blob/master/Documentation/ceph-cluster-crd.md#cluster-wide-resources-configuration-settings
  # Get ceph object store
  cephobjectstore=$(kubectl -n rook-ceph get cephobjectstore --no-headers | cut -d' ' -f1)
  validate_exec "[ERROR]: Failed to get ceph object store. Exiting !!!"
  validateNullCheck "$cephobjectstore" "cephobjectstore"

  # Patch ceph object store
  kubectl patch cephobjectstore -n rook-ceph ${cephobjectstore} --type='json' -p '[{"op":"replace","path":"/spec/gateway/resources/requests/cpu","value":"200m"}]'
  validate_exec "[ERROR]: Failed to patch ceph object store. Exiting !!!"

  # Get ceph cluster
  cephcluster=$(kubectl -n rook-ceph get cephcluster --no-headers | cut -d' ' -f1)
  validate_exec "[ERROR]: Failed to get ceph cluster. Exiting !!!"
  validateNullCheck "$cephcluster" "cephcluster"

  # patch ceph cluster's mgr request cpu
  kubectl patch cephcluster -n rook-ceph ${cephcluster} --type='json' -p '[{"op":"replace","path":"/spec/resources/mgr/requests/cpu","value":"100m"}]'
  validate_exec "[ERROR]: Failed to patch ceph cluster mgr request cpu. Exiting !!!"

  # patch ceph cluster's mon request cpu
  kubectl patch cephcluster -n rook-ceph ${cephcluster} --type='json' -p '[{"op":"replace","path":"/spec/resources/mon/requests/cpu","value":"100m"}]'
  validate_exec "[ERROR]: Failed to patch ceph cluster mon request cpu. Exiting !!!"

  # patch ceph cluster's osd request cpu
  kubectl patch cephcluster -n rook-ceph ${cephcluster} --type='json' -p '[{"op":"replace","path":"/spec/resources/osd/requests/cpu","value":"100m"}]'
  validate_exec "[ERROR]: Failed to patch ceph cluster osd request cpu. Exiting !!!"

  # Get ceph file system
  cephfilesystem=$(kubectl -n rook-ceph get cephfilesystem --no-headers | cut -d' ' -f1)
  validate_exec "[ERROR]: Failed to get ceph file system. Exiting !!!"
  validateNullCheck "$cephfilesystem" "cephfilesystem"

  kubectl patch cephfilesystem -n rook-ceph "${cephfilesystem}" --type='json' -p '[{"op":"replace","path":"/spec/metadataServer/resources/requests/cpu","value":"100m"}]'
  validate_exec "[ERROR]: Failed to patch ceph file system. Exiting !!!"
fi

# Create service account if not exits
kubectl -n default create serviceaccount provision --dry-run=client -o yaml | kubectl apply -f -
validate_exec "[ERROR]: Failed to create service account provision. Exiting !!!"

# Create cluster role binding if not exits
kubectl -n default create clusterrolebinding provision-admin --clusterrole=cluster-admin --serviceaccount=default:provision --dry-run=client -o yaml | kubectl apply -f -
validate_exec "[ERROR]: Failed to create cluster role binding provision-admin. Exiting !!!"

cd ../..
