#!/bin/bash

echo "Starting istio setup"

#download istio
curl -sL "https://github.com/istio/istio/releases/download/1.5.6/istio-1.5.6-linux.tar.gz" | tar xz
cd istio-1.5.6
chmod +x ./bin/istioctl

#install using istioctl
./bin/istioctl manifest apply --logtostderr \
--set installPackagePath=./install/kubernetes/operator \
--set values.global.proxy.resources.limits.cpu=100m \
--set values.global.proxy.resources.limits.memory=128Mi \
--set values.sidecarInjectorWebhook.rewriteAppHTTPProbe=true \
--set values.global.disablePolicyChecks=false \
--set values.global.configValidation=false \
--set values.prometheus.retention=1d \
--set values.gateways.istio-ingressgateway.sds.enabled=true \
--set meshConfig.accessLogFile="/dev/stdout" \
--set components.cni.namespace=kube-system \
--set values.cni.cniBinDir=/var/lib/cni/bin \
--set values.cni.cniConfDir=/etc/cni/multus/net.d \
--set values.cni.chained=false \
--set values.cni.cniConfFileName="istio-cni.conf" \
--set values.sidecarInjectorWebhook.injectedAnnotations."k8s\.v1\.cni\.cncf\.io/networks"=istio-cni

#wait for deployment to be complete
oc -n istio-system wait --for=condition=available deployment --all --timeout=600s

oc -n istio-system expose svc istio-ingressgateway

echo "Istio setup completed successfully"