#!/bin/bash

PROVISION_SERVICE_ROLE_BINDING=$(oc get clusterrolebinding | grep provision-admin-aif-core)

if [ "${PROVISION_SERVICE_ROLE_BINDING}" != '' ];
then
  #Delete clusterrolebinding
  echo "[INFO]: Deleting provision-admin clusterrolebinding"
  oc delete  clusterrolebinding provision-admin-aif-core
fi

echo "[INFO]: Installing Kots Admin UI"

KOTS_VERSION=v1.22.0
curl -L -o kots_linux_amd64.tar.gz https://github.com/replicatedhq/kots/releases/download/$KOTS_VERSION/kots_linux_amd64.tar.gz
tar xzf kots_linux_amd64.tar.gz

sudo cp kots /usr/local/bin/kubectl-kots

export PATH=$PATH:/usr/local/bin/

kubectl kots install aif-core --namespace aif-core --port-forward=false

oc create -n aif-core serviceaccount provision

oc create -n aif-core clusterrolebinding provision-admin-aif-core --clusterrole=cluster-admin --serviceaccount=aif-core:provision

oc -n aif-core delete route kotsadm

read -p 'Do you want to enable https for kotsadmin? You will have to provide paths tls cert and key files. Please enter (y/n) :' enable_https 

if [[ "$enable_https" == "y" || "$enable_https" == "Y" ]];
then
  read -p 'Path to TLS certificate: ' tls_cert_file
  read -p 'Path to TLS key: ' tls_key_file

  oc -n aif-core create route edge --service=kotsadm --cert=${tls_cert_file} --key=${tls_key_file}

  HOST=$(oc -n aif-core get route kotsadm -o jsonpath='{.spec.host}')
  echo "[INFO]: Kots Admin UI installed successfully. Access it on https://${HOST}"
else
  oc -n aif-core expose svc kotsadm
  HOST=$(oc -n aif-core get route kotsadm -o jsonpath='{.spec.host}')
  echo "[INFO]: Kots Admin UI installed successfully. Access it on http://${HOST}"
fi

INGRESS_HOST=$(kubectl -n istio-system get svc istio-ingressgateway -o jsonpath='{.status.loadBalancer.ingress[0].ip}')
echo "[INFO]: Please use $INGRESS_HOST as your ingress host IP in aifabric deployment. If this is not printed properly please run 'kubectl -n istio-system get svc istio-ingressgateway' to get the external IP to be used with AIFabric."