#!/bin/bash
#
#

# Function to check if the osd pods are ready or not
osd_pods_ready() {
  pod_list=$(oc -n rook-ceph get pods -l app=rook-ceph-osd -o 'jsonpath={..status.conditions[?(@.type=="Ready")].status}' | tr " " "\n")

  osdPodsReady=true;

  if [ "${pod_list}" = '' ];
  then
        osdPodsReady=false;
        return;
  fi

  for podStatus in $pod_list
  do
      if [ $podStatus != "True" ];
      then
            osdPodsReady=false
      fi
  done

}

#Check if the pvc is Bound
pvc_bound() {
  pvcClaimStatus=$(oc get pvc -o=jsonpath="{.items[*].status.phase}")
  
  pvcClaimBound=true;
  
  if [ $pvcClaimStatus != "Bound" ]
  then
    pvcClaimBound=false;
  fi
}


echo "[INFO]: Started rook-ceph installation"
cd ../ceph-installation

oc create -f common.yaml

oc create -f operator-openshift.yaml

oc create -f cluster-test.yaml

#Check if the osd pods are ready now
osd_pods_ready;

counter=1

while [ $osdPodsReady != true ];
do

    if [ "${counter}" -gt 20 ];
    then
      echo "Ceph installation didn't succeed in 600s. Exiting !!!"
      exit 1
    fi

    osd_pods_ready;
    echo "rook-ceph-osd pods not ready yet. Waiting for pods.." && sleep 30;    
    counter=$((counter+1))
  
done


oc create -f ceph-storage-class.yaml

oc create -f ceph-object-store.yaml

# mark other storage classes as non-default
storageclasses=$(kubectl get storageclass --no-headers -o custom-columns=NAME:.metadata.name)
for class in $storageclasses; do
  oc patch storageclass $class -p '{"metadata": {"annotations":{"storageclass.kubernetes.io/is-default-class":"false"}}}'
done

# mark ceph storage class as default one
oc patch storageclass default -p '{"metadata": {"annotations":{"storageclass.kubernetes.io/is-default-class":"true"}}}'

#Block storage verification
oc create -f mysql.yaml

#Check if pvc is bound
pvc_bound;

while [ $pvcClaimBound != true ];
do
    pvc_bound;
    echo "Waiting for PVC to be bound." && sleep 10;
done

#Delete PVC
oc delete -f mysql.yaml

cd ../scripts
echo "Ceph installation completed successfully"