function validateAndPrint() {
  if [ $? -ne 0 ]; 
  then
      echo "[ERROR]: $1 !!! Exiting !!!"
      exit 1   
  fi
}

contains() {
  echo "$1" | grep -q "$2"
}

az group show --name $RESOURCEGROUP > /dev/null

validateAndPrint "Provided resource group $RESOURCEGROUP does not exist"

az acr show --resource-group $RESOURCEGROUP --name $acrName > /dev/null

validateAndPrint "Provided ACR $acrName does not exist in the resource group $RESOURCEGROUP"

az aks get-credentials -g $RESOURCEGROUP -n $AKSCLUSTERNAME

validateAndPrint "Could not log in to the cluster $AKSCLUSTERNAME in RG $RESOURCEGROUP"

az storage account show --resource-group $RESOURCEGROUP --name $storageAccountName1 > /dev/null

validateAndPrint "Provided storage account $storageAccountName1 does not exist in the resource group $RESOURCEGROUP"

az group show --name $WORKER_RESOURECEGROUP > /dev/null

validateAndPrint "Provided worker resource group $WORKER_RESOURECEGROUP does not exist"

ACR_CREDS=$(az acr credential show --resource-group $RESOURCEGROUP --name $acrName | jq --arg loginKey  $acrLoginKey '.passwords[] | select(.value==$loginKey)')

if [[ "$ACR_CREDS" == "" ]];
then
  echo "ACR Login key not found. Please check if the provided value is correct."
  exit 1
fi

STORAGE_KEY=$(az storage account keys list --resource-group $RESOURCEGROUP --account-name $storageAccountName1 | jq --arg storageAccessKey $storageAccountKey1 '.[] | select(.value==$storageAccessKey)')

if [[ "$STORAGE_KEY" == "" ]];
then
  echo "Storage account key not found. Please check if the provided storage account key is correct."
  exit 1
fi

az extension add --name application-insights

APP_INSIGHTS=$(az monitor app-insights component show --resource-group $RESOURCEGROUP | jq --arg appinsightsKey $applicationInsightsKey '.[] | select(.instrumentationKey==$appinsightsKey)')

if [[ "$APP_INSIGHTS" == "" ]];
then
  echo "Appinsights instance not found. Please check if the appinsights instance key is correct and is present in the give resource group."
  exit 1
fi

MAJOR_VERSION=$(kubectl version -o json | jq .serverVersion.major)
MINOR_VERSION=$(kubectl version -o json | jq .serverVersion.minor)

KUBERNETES_VERSION=$(echo $MAJOR_VERSION.$MINOR_VERSION | sed -e 's/"//g')

SUPPORTED_KUBERNETES_VERSIONS="1.16 1.17 1.18 1.19"

if contains "$SUPPORTED_KUBERNETES_VERSIONS" "$KUBERNETES_VERSION" ;
then
  echo "[INFO]: Supported kubernetes version found $KUBERNETES_VERSION"
else
  echo "[ERROR]: Unsupported kubernetes version $KUBERNETES_VERSION, we currenlty support only ${SUPPORTED_KUBERNETES_VERSIONS}";
  exit 1
fi

NUMBER_OF_NODEPOOLS=$(az aks nodepool list --resource-group $RESOURCEGROUP --cluster-name $AKSCLUSTERNAME | jq length)

if [[ "$NUMBER_OF_NODEPOOLS" -gt 1 ]];
then
  echo "[INFO]: $NUMBER_OF_NODEPOOLS nodepools exist in the cluster"
else
  echo "[ERROR]: There should be at least 2 nodepools in the cluster. 1 with CPU nodes and another with GPU nodes."
  exit 1
fi

NODE_TAINTS=$(az aks nodepool list --resource-group $RESOURCEGROUP --cluster-name $AKSCLUSTERNAME | jq '.[].nodeTaints')
GPU_TAINT_EXISTS=false

for taint in $NODE_TAINTS; do
  if [[ "${taint}" == "\"nvidia.com/gpu=present:NoSchedule\"" ]];
  then
    export GPU_TAINT_EXISTS=true
  fi
done

if [[ "$GPU_TAINT_EXISTS" == "true" ]];
then
  echo "[INFO]: GPU tainted node pool exists."
else
  echo "[ERROR]: There should be at least one nodepool with nvidia.com/gpu=present:NoSchedule taint."
  exit 1
fi