#!/bin/bash

echo "[INFO]: Starting Kubernetes orchestrator type validation for nodes.."

node_list=$(docker node ls --format "{{.Hostname}}" | tr " " "\n")

for node in $node_list
do

  nodeOrchestratorTypeLabel=$(docker node inspect $node | grep -i "com.docker.ucp.orchestrator.swarm")

  if [ "${nodeOrchestratorTypeLabel}" = '' ];
  then
    # Check if it is kubernetes only node
    nodeKubernetesLabel=$( docker node inspect $node | grep -i "com.docker.ucp.orchestrator.kubernetes")

    if [ "${nodeKubernetesLabel}" != '' ];
    then
      nodeKubernetesLabelValue=$(echo $nodeKubernetesLabel | cut -d ":" -f 2 |  sed -e 's/^[[:space:]]*//' | tr -d '"')
         
      if [ "${nodeKubernetesLabelValue}" = "true" ];
      then
        kubernetesOnlyNodes=$(echo "${kubernetesOnlyNodes}${node} " )
      fi
    fi
  fi
done

if [ "${kubernetesOnlyNodes}" != '' ];
then
  echo "[INFO]: Detected node(s) with orchestrator type Kubernetes: ${kubernetesOnlyNodes}"
else
  echo "[ERROR]: No node with Orchestrator type Kubernetes found in the cluster.\
Make sure that there is at least one node in the cluster with Orchestrator type Kubernetes.\
Exiting.."
  
  exit 1
fi