# given the device name, returns the size in GB
sizeInGB() {
  SIZE_IN_BYTES=$(lsblk $1 -b --nodeps --noheadings --paths --output SIZE)
  SIZE=$(( $SIZE_IN_BYTES/1024/1024/1024 ))
  echo $SIZE
}

# If size of the device is less than some expected value, process will exit
breakIfDiskSizeLess() {
  SIZE_IN_GB=$(sizeInGB $1)
  if [[ $SIZE_IN_GB -lt $2 ]];
  then
    echo "[ERROR]: Size of the device having folder $3 is less than $2 GB. Please increase the size of device $1 and retry. Exiting.."
    exit 1
  fi
}

# Check if /var/lib/docker is mount with a separate device or check for /var/lib
if [[ -d "/var/lib/docker" ]];
then
  DEVICE_NAME_DOCKER=$(df /var/lib/docker | sed -n '2 p' | cut -d' ' -f1)
else
  DEVICE_NAME_DOCKER=$(df /var/lib/ | sed -n '2 p' | cut -d' ' -f1)
fi

# Check if /var/lib/kubelet is mount with a separate device or check for /var/lib
if [[ -d "/var/lib/kubelet" ]];
then
  DEVICE_NAME_KUBELET=$(df /var/lib/kubelet | sed -n '2 p' | cut -d' ' -f1)
else
  DEVICE_NAME_KUBELET=$(df /var/lib/ | sed -n '2 p' | cut -d' ' -f1)
fi

# If both folders are under same device, check the size to be 200GB or check for the size to be 125GB and 100GB for docker and kubelet
if [[ "${DEVICE_NAME_DOCKER}"=="${DEVICE_NAME_KUBELET}" ]];
then
  breakIfDiskSizeLess $DEVICE_NAME_DOCKER 200 "/var/lib"
else
  breakIfDiskSizeLess $DEVICE_NAME_DOCKER 125 "/var/lib/docker"
  breakIfDiskSizeLess $DEVICE_NAME_KUBELET 100 "/var/lib/kubelet"
fi

echo "[INFO]: Sizes of docker and kubelet directory seem to be sufficient."