#!/bin/bash

# find memory info in KB
MEMORY_INFO=$( grep MemTotal /proc/meminfo )
if [[ -z $MEMORY_INFO ]]; then
    echo "[ERROR] Fetching system memory info failed."
    exit 1
fi

# parse and get the memory in kb
MEMORY_IN_KB=$( echo $MEMORY_INFO | cut -d' ' -f2 )
if [[ -z $MEMORY_IN_KB ]]; then
    echo "[ERROR] System memory infomation not available."
    exit 1
fi

# convert memory info from kb to gb
MEMORY_IN_GB=$(( $MEMORY_IN_KB/1000/1000 ))
# Stop installation if memory size is less the 32 GB
if [[ $MEMORY_IN_GB -lt 32 ]]; then
    echo "[ERROR] Device with memory size ${MEMORY_IN_GB}GB is less than minimum required memory size i.e 32GB"
    exit 1
fi

if [[ $MEMORY_IN_GB -ge 32 && $MEMORY_IN_GB -lt 52 ]]; then
    echo "[Warning] Device with memory size ${MEMORY_IN_GB}GB is less than recommended memory size i.e 52GB"
else
    echo "[INFO] Device available with size ${MEMORY_IN_GB}GB"
fi
