#!/bin/bash

function BytesToHuman() {

    # https://unix.stackexchange.com/questions/44040/a-standard-tool-to-convert-a-byte-count-into-human-kib-mib-etc-like-du-ls1/259254#259254
    b=$1; d=''; s=0; S=(Bytes {K,M,G,T,E,P,Y,Z}iB)
    while ((b > 1024)); do
        d="$(printf ".%02d" $((b % 1024 * 100 / 1024)))"
        b=$((b / 1024))
        let s++
    done
    echo "$b$d ${S[$s]}"

} # BytesToHuman ()

avail_device_count=0
#Get all devices
disks=$( lsblk --all --paths --nodeps --pairs --output NAME | grep -v -e "loop" -e "rbd" -e "ceph" )
IFS=$'\n'
set -o noglob  # or more tersely set -f

#Loop through all devices
for disk in $disks; do
  DEVICE=$(echo "$disk" | cut -f2 -d= | tr -d '"')
  FS_KEY_VAL=$(udevadm info --query=property "$DEVICE" | grep "ID_FS_TYPE")
  FILE_SYSTEM=$(echo "$FS_KEY_VAL" | cut -f2 -d= | tr -d '"')
  RO=$(lsblk $DEVICE --nodeps --noheadings --output RO)
  DEVICE_TYPE=$(lsblk $DEVICE --nodeps --noheadings --output TYPE)
  PARTITION_COUNT=$(lsblk $DEVICE --bytes --pairs --output NAME,SIZE,TYPE,PKNAME | grep "part" | wc -l)
  #if partition_count is emtpy initialize it to zero
  if [[ -z $PARTITION_COUNT ]];
  then
    PARTITION_COUNT=0
  fi
  PARENT_DEVICE=$(lsblk $DEVICE --nodeps --noheadings --paths --output PKNAME)
  SIZE_IN_BYTES=$(lsblk $DEVICE -b --nodeps --noheadings --paths --output SIZE)
  SIZE=$(( $SIZE_IN_BYTES/1024/1024/1024 ))

  echo "Device attached to the Machine, Device: $DEVICE FileSystem: $FILE_SYSTEM RO: $RO DeviceType: $DEVICE_TYPE PartitionCount: $PARTITION_COUNT ParentDevice: $PARENT_DEVICE Size: $(BytesToHuman $SIZE_IN_BYTES)"

  # if the device has file system associated with it, then ceph cant use the disk
  if [[ ! -z $FILE_SYSTEM ]];
  then
    echo "Device: $DEVICE cant be used by ceph as it has an FileSystem: $FILE_SYSTEM associated with it"
  fi

  #If the Device has paritions then ceph cant use the device
  if [[ $PARTITION_COUNT -gt 0 ]];
  then
    echo "Device: $DEVICE cant be used by ceph as it has Partitions: $PARTITION_COUNT associated with it"
  fi

  if [[ -z $PARENT_DEVICE && -z $FILE_SYSTEM && $PARTITION_COUNT -eq 0 && $RO -eq 0 ]]
  then
    if [[ "$DEVICE_TYPE" == "disk" || "$DEVICE_TYPE" == "ssd" || "$DEVICE_TYPE" == "crypt" || "$DEVICE_TYPE" = "lvm" ]];
    then
      echo "Available Device for CEPH Consumption is $DEVICE Size: $(BytesToHuman $SIZE_IN_BYTES) DeviceType: $DEVICE_TYPE"

      if [ $SIZE -ge 200 ];
      then
        avail_device_count=$((avail_device_count+1))
      fi

      if [[ $SIZE -ge 200 && $SIZE -lt 500 ]];
      then
        echo "Device $DEVICE available for ceph consumption but its size $(BytesToHuman $SIZE_IN_BYTES) is less than recommended size i.e 500GB"
      fi
    fi
  fi

done

if [ $avail_device_count -eq 0 ];
then
  echo "Sorry, There arent any RAW devices available for CEPH consumption which are greater than 200GB in size!!"
  exit 1
fi
