#!/bin/bash

#execute function
execute() {
  bash $1
  if [ $? -ne 0 ];
  then
    echo "[ERROR]: Installation failed. Exiting !!!"
    exit 1
  fi
}

execute_preflight_checks() {
  #Check if kubectl is installed
  if [[ "${PLATFORM}" != "azure" ]];
  then
    KUBECTL_VERSION=$( command -v kubectl )
    if [ ! -z "${KUBECTL_VERSION}" ];
    then
      echo "[INFO]: Found Kubectl $KUBECTL_VERSION. Start checking rook ceph"
      found=$(kubectl get ns | grep rook-ceph | cut -d' ' -f1)
      # check if rook-ceph not exit
      if [ "${found}" == "rook-ceph" ];
      then
        echo "[INFO]: Rook ceph alreay installed. Skipping preflight validation"
        return;
      fi
    fi
  fi
  platform_preflight_checks;
}

platform_preflight_checks() {
  if [ -d "preflight/$PLATFORM" ];
  then
    # Execute the platform specific preflight checks
    echo "[INFO]: Starting preflight checks for platform ${PLATFORM}"

    for file in preflight/$PLATFORM/*.sh
    do
      execute $file;
    done
  else
    echo "[INFO]: No platform specific preflight checks defined for platform ${PLATFORM}. Proceeding.."
  fi
}

# Script execution starts here
# platform_preflight_checks;
execute_preflight_checks;