#!/bin/bash

# Ask for user input for certificates
echo "Enter your TLS certificates to access KotsAdmin as HTTPS. 
Provide the folder path where the TLS key and certitficates are present.";

#Get FQDN
echo "Enter the FQDN assigned to your certificate."

read -p 'Enter FQDN: ' fqdn

retry=1;

# Check if the folder exists
while [ true ];
do

  # Get folder location to certificates
  read -p 'Path to TLS certificate and key: ' tls_folder_path

  if [ -d "${tls_folder_path}" ];
  then 
    
    # copy the files to nginx-tls folder
    echo "Copying the tls certificates"

    if [ -f "${tls_folder_path}/tls.crt" ];
    then
      cp ${tls_folder_path}/tls.crt ../existing-cluster-tls/nginx-tls/
    else
      echo "[ERROR]: tls.crt does not exist in the specified folder. Exiting.."
      exit 1;
    fi

    if [ -f "${tls_folder_path}/tls.key" ];
    then
      cp ${tls_folder_path}/tls.key ../existing-cluster-tls/nginx-tls/
    else
      echo "[ERROR]: tls.key does not exist in the specified folder. Exiting.."
      exit 1;
    fi

    break;

  else
  	
  	if [ $retry -gt 2 ];
  	then
  	  echo "[ERROR]: Retry limit reached. Provided folder doesn't contain TLS certificates. Exiting.."
  	  exit 1;
  	else
      echo "[WARN]: Folder entered does not exist. Please enter again."
      retry=$(( retry + 1 ))
  	fi

  fi

done

kubectl -n aif-core create secret generic kotsadm-nginx-tls --from-file=../existing-cluster-tls/nginx-tls

# make changes in the virtualhost.conf file to replace FQDN

kubectl -n aif-core create configmap kotsadm-nginx-conf --from-file=../existing-cluster-tls/nginx-conf

#Reverse proxy Deployment
kubectl -n aif-core apply -f ../existing-cluster-tls/nginx-proxy/

KOTSADMIN_PORT=$(kubectl -n aif-core get svc kotsadm-nginx-proxy -o jsonpath='{.spec.ports[?(@.name=="https")].nodePort}')

sed -i 's|KOTSADM_HTTPS_PORT_PLACEHOLDER|'$KOTSADMIN_PORT'|g' ../existing-cluster-tls/nginx-conf/virtualhost.conf
sed -i 's|FQDN_PLACEHOLDER|'$fqdn'|g' ../existing-cluster-tls/nginx-conf/virtualhost.conf

echo "[INFO]: Kots Admin UI installed successfully. Access it on https://$fqdn:$KOTSADMIN_PORT or https://$UCP_HOST:$KOTSADMIN_PORT. Make sure that the port $KOTSADMIN_PORT is accepting connections"