#!/bin/bash

#execute function
execute() {
  bash $1
  if [ $? -ne 0 ];
  then
    echo "[ERROR]: Service Installation Failed. Exiting !!!"
    exit 1
  fi
}

install_service() {
  # Total steps
  total_steps=3
  current_step=1

  if [ "${SILENT_INSTALL_ENABLE}" == true ];
  then
    total_steps=4
    echo "<----------- Total steps: ${total_steps} Current step: ${current_step}  Estimated time: 2s ----------->"
    execute prepare-config.sh
    current_step=$(( current_step + 1 ))
  fi
  

  echo "<----------- Total steps: ${total_steps} Current step: ${current_step}  Estimated time: 2s ----------->"
  if [ "${SILENT_INSTALL_ENABLE}" == true ];
  then
    echo "[INFO] Start provisioning service ..."
    kubectl kots install aif-core --license-file ${LICENSE_FILE_PATH} --config-values ./config-temp.yaml --namespace aif-core  --port-forward=false
    echo "[INFO] Service provision completed ..."
  else
    kubectl kots install aif-core --namespace aif-core  --port-forward=false
  fi
  current_step=$(( current_step + 1 ))

  echo "<----------- Total steps: ${total_steps} Current step: ${current_step}  Estimated time: 2s ----------->"
  bash ../common/kots-https-existing-cluster.sh
  current_step=$(( current_step + 1 ))

  echo "<----------- Total steps: ${total_steps} Current step: ${current_step}  Estimated time: 2s ----------->"
  # If https is not set up, then expose KotsUI as http
  https_installed=$(kubectl -n aif-core get svc | grep kotsadm-nginx-proxy)

  if [ "${https_installed}" = '' ];
  then
    #Patch kotsadm service 
    kubectl patch svc -n aif-core kotsadm --type='json' -p '[{"op":"replace","path":"/spec/type","value":"LoadBalancer"}]'

    KOTSADMIN_HTTP_PORT=$(kubectl -n aif-core get svc kotsadm -o 'jsonpath={.spec.ports[0].nodePort}')

    echo "[INFO]: Kots Admin UI installed successfully. Access it on http://$UCP_HOST:$KOTSADMIN_HTTP_PORT. Make sure that the port $KOTSADMIN_HTTP_PORT is accepting connections"
  fi
  current_step=$(( current_step + 1 ))
}

install_service;