
#!/bin/bash

# Parse command line arguments
TEMP=`getopt -o a:p:g:s:c:l:R:C:e:A:U:P:W:D:S:X:I:E:Z:B:i:G:Y: --long licenseAgreement:,platform:,gpuInstalled:,silentInstall:,configFilePath:,licenseFilePath:,resourceGroup:,clusterName:,exposeKots:,acrHost:,acrUser:,acrKey:,workerResourcegroup:,dnsPrefix:,storageAccountName:,storageAccountAccessKey:,appInsightsKey:,email:,isPrivate:,bundleLocation:,infraFolder:,isAirgap:,onlyAttachGpu: -- "$@"`
eval set -- "$TEMP"

while true ; do
    case "$1" in
        -a|--licenseAgreement)
            export LICENSE_AGREEMENT=$2 ; shift 2 ;;
        -p|--platform)
            export platform=$2 ; shift 2 ;;
        -g|--gpuInstalled)
            export gpu_installed=$2 ; shift 2 ;;
        -s|--silentInstall)
            export is_silent_install=$2 ; shift 2 ;;
        -c|--configFilePath)
            export config_file_path=$2 ; shift 2 ;;
        -l|--licenseFilePath)
            export license_file_path=$2 ; shift 2 ;;
        -R|--resourceGroup)
            export RESOURCEGROUP=$2 ; shift 2 ;;
        -C|--clusterName)
            export AKSCLUSTERNAME=$2 ; shift 2 ;;
        -e|--exposeKots)
            export EXPOSE_KOTS=$2 ; shift 2 ;;
        -A|--acrHost)
            export acrLoginServer=$2 ; shift 2 ;;
        -U|--acrUser)
            export acrUser=$2 ; shift 2 ;;
        -P|--acrKey)
            export acrLoginKey=$2 ; shift 2 ;;
        -W|--workerResourcegroup)
            export WORKER_RESOURECEGROUP=$2 ; shift 2 ;;
        -D|--dnsPrefix)
            export DNSNAME=$2 ; shift 2 ;;
        -S|--storageAccountName)
            export storageAccountName1=$2 ; shift 2 ;;
        -X|--storageAccountAccessKey)
            export storageAccountKey1=$2 ; shift 2 ;;
        I|--appInsightsKey)
            export applicationInsightsKey=$2 ; shift 2 ;;
        E|--email)
            export USER_EMAIL=$2 ; shift 2 ;;
        Z|--isPrivate)
            export IS_PRIVATE=$2 ; shift 2 ;;
        B|--bundleLocation)
            export BUNDLE_LOCATION=$2 ; shift 2 ;;
        i|--infraFolder)
            export INFRA_FOLDER=$2 ; shift 2 ;;
        G|--isAirgap)
            export IS_AIRGAP=$2 ; shift 2 ;;
        -Y|--onlyAttachGpu)
            export ONLY_ATTACH_GPU=$2 ; shift 2 ;;
        --) shift ; break ;;
        *) echo "Internal error!" ; exit 1 ;;
    esac
done

#execute function
execute() {
  bash $1
  if [ $? -ne 0 ];
  then
    echo "[ERROR]: Installation failed. Exiting !!!"
    exit 1
  fi
}


# presetup function
presetup() {
  source util/license-agreement.sh
  source util/read-input.sh
  execute preflight/preflight-validation.sh
}

# setup function
setup() {
    echo "Start provisioning infra ..."
    cd infra/${PLATFORM}
    execute infra-provision.sh
    cd ../..
    source util/onebox-env-setup.sh
    execute util/add-license-agreement.sh
    echo "Infra provisioning completed ..."
    cd service/${PLATFORM}
    execute service-provision.sh
    cd ../..    
}

if [[ "${ONLY_ATTACH_GPU}" = "y" || "${ONLY_ATTACH_GPU}" = "Y" ]];
then
    echo "[INFO] Running only GPU Driver Scripts."
    cd infra/common/scripts
    bash attach_gpu_drivers.sh
    cd ../../..
    exit 0
fi

echo "Starting k8 unified installation ..."
presetup;
setup;