#!/bin/bash

#Read platform input
get_platform_input() {

#Ask for platform
if [ -z "$platform" ];
then
  read -p 'Enter Platform : ' platform
else
  echo "[INFO]: Platform set with value $platform"
fi

#Convert to lowercase
platform=$(echo "$platform" | tr '[:upper:]' '[:lower:]')

export PLATFORM=$platform;

#Validate platform
validate_platform;

}

#Validate platform
validate_platform() {

supported_platforms=(onebox azure);

if [ "$platform" = '' ];
then
  echo "[ERROR]: Platform can't be empty. Enter a valid platform. Supported platforms are ${supported_platforms[@]}";
  exit 1;
fi

# Check if the platform entered is supported one
validPlatform=false;

for i in "${supported_platforms[@]}"
do
    if [ "$i" == "$PLATFORM" ] ; 
    then
      validPlatform=true;
      break;
    fi
done

if [ "$validPlatform" = false ];
then
  echo "[ERROR]: Platform is not valid. Supported platforms are ${supported_platforms[@]}"
  exit 1;
fi
}

#Read services input
get_services_input() {

#Ask for services
# echo "Enter service(s) separated by space or tab and then press Enter"
# read -a services

export SERVICES=aifabric;

#Validate services
# validate_services;

}

#Validate platform
validate_services() {

supported_services=(aifabric);

if [ -z "$services" ]; 
then
  echo "[ERROR]: No service provided. Enter a valid service. Supported services are ${supported_services[@]}";
  exit 1;
fi

# Check if the service entered is supported one

for i in "${services[@]}"
do  
validService=false;

  for j in "${supported_services[@]}"
  do
      #Convert to lowercase
      i=$(echo "$i" | tr '[:upper:]' '[:lower:]')

      if [ "$i" == "$j" ] ; 
      then
        validService=true;
        break;
      fi
  done

  if [ "$validService" = false ];
  then
    echo "[ERROR]: Service is not valid. Supported services are ${supported_services[@]}"
    exit 1;
  fi

done

}

#Read GPU driver installed
get_gpu_input() {

if [ "${PLATFORM}" = 'onebox' ];
then
  #Ask for services
  if [ -z "$gpu_installed" ];
  then
    echo "Is the GPU driver installed on any node(s) in the cluster.Please enter yes('y') or no('n') below"
    read -p 'GPU driver installed?(y/n) : ' gpu_installed
  fi

  if [ "${gpu_installed}" = 'y' ];
  then
    export GPU_DRIVER_INSTALLED=true;
  fi
fi

}

#Read GPU driver installed
silent_installation_input() {
  if [ -z "$is_silent_install" ];
  then
    #Ask for silent installation option
    read -p 'Do you want silent installation? (y/n) : ' is_silent_install
  else
    echo "[INFO] Silent installation set with value ${is_silent_install}"
  fi
  if [ "${is_silent_install}" = 'y' ];
  then
    if [ -z "$license_file_path" ];
    then
      read -p 'License file path : ' license_file_path
    else
      echo "License file path ${license_file_path}"
    fi

    if [ -e ${license_file_path} ]
    then
      export LICENSE_FILE_PATH=${license_file_path};
    else
      echo "[ERROR]: License file at ${license_file_path} not present"
      exit 1;
    fi

    if [ -z "$config_file_path" ];
    then
      read -p 'Configuration file path : ' config_file_path
    else
      echo "Configuration file path ${config_file_path}"
    fi

    if [ -e ${config_file_path} ]
    then
      export CONFIG_FILE_PATH=${config_file_path};
    else
      echo "[ERROR]: Configuration file at ${config_file_path} not present"
      exit 1;
    fi
    export SILENT_INSTALL_ENABLE=true;
  fi
}

# Function to load env.sh
load_env() {
  
  if [ -d ucp_bundle ];
  then
    cd ucp_bundle
    source env.sh
    cd ..
  else
    echo "[ERROR]: UCP bundle does not exist. Exiting"
	exit 1
  fi
  
  echo "[INFO]: Loaded env successfully"
}

get_ucp_input() {

#Ask for UCP URL
read -p 'UCP Host (IP or FQDN) : ' ucphost

#Ask for UCP username
read -p 'UCP username : ' ucpuser

#Ask for UCP password
read -sp 'UCP password : ' ucppassword

export UCP_HOST=$ucphost;
export UCP_USERNAME=$ucpuser;
export UCP_PASSWORD=$ucppassword;
}

prepare_dockeree_env() {
  get_ucp_input;
  execute util/docker-ucp-client-bundle-download.sh
  load_env;
}

read_azure_input_values() {

  if [ -z "$RESOURCEGROUP" ];
  then
    read -p 'Please enter the reasource group in which AKS Cluster is deployed : ' RESOURCEGROUP
  fi

  if [ -z "$AKSCLUSTERNAME" ];
  then
    read -p 'Please enter the AKS Cluster Name : ' AKSCLUSTERNAME
  fi

  if [ -z "$acrLoginServer" ];
  then
    read -p 'Please enter the Azure Container Registry endpoint : ' acrLoginServer
  fi

  if [ -z "$acrUser" ];
  then
    read -p 'Please enter the Azure Container Registry username : ' acrUser
  fi

  if [ -z "$acrLoginKey" ];
  then
    read -sp 'Please enter the Azure Container Registry password : ' acrLoginKey
    echo ""
  fi
  
  if [ -z "$WORKER_RESOURECEGROUP" ];
  then
    read -p 'Please enter the resource group name where AKS worker pools are deployed : ' WORKER_RESOURECEGROUP
  fi

  if [ -z "$DNSNAME" ];
  then
    read -p 'Please enter the preferred dns prefix for aifabric deployment : ' DNSNAME
  fi

  if [ -z "$storageAccountName1" ];
  then
    read -p 'Please enter the storage account name to be used for AIFabric : ' storageAccountName1
  fi

  if [ -z "$storageAccountKey1" ];
  then
    read -p 'Please enter the key for the storage account provided : ' storageAccountKey1
  fi

  if [ -z "$EXPOSE_KOTS" ];
  then
    read -p 'Do you want to expose kots-admin service (y/n) : ' EXPOSE_KOTS
  fi

  if [ -z "$applicationInsightsKey" ];
  then
    read -p 'Please enter the application insights key : ' applicationInsightsKey
  fi

  if [ -z "$USER_EMAIL" ];
  then
    read -p 'Please enter the user email address, which will be used for certificate related notifications : ' USER_EMAIL
  fi

  if [ -z "$IS_PRIVATE" ];
  then
    read -p 'Please enter (y/n) indicating if the AKS cluster is private or not : ' IS_PRIVATE
  fi

  export PRIVATE_CLUSTER=false
  if [[ "${IS_PRIVATE}" == "y" || "${IS_PRIVATE}" == "Y" ]];
  then
    export PRIVATE_CLUSTER=true
  fi

  export expose_kots=false
  if [[ "${EXPOSE_KOTS}" == "y" || "${EXPOSE_KOTS}" == "Y" || "${PRIVATE_CLUSTER}" == "true" ]];
  then
    export expose_kots=true
  fi
  
  export RESOURCEGROUP=$RESOURCEGROUP
  export AKSCLUSTERNAME=$AKSCLUSTERNAME
  export acrLoginServer=$acrLoginServer
  export acrName=$acrUser
  export acrLoginKey=$acrLoginKey
  export WORKER_RESOURECEGROUP=$WORKER_RESOURECEGROUP
  export DNSNAME=$DNSNAME
  export storageAccountName1=$storageAccountName1
  export storageAccountKey1=$storageAccountKey1
  export applicationInsightsKey=$applicationInsightsKey
  export USER_EMAIL=$USER_EMAIL
}

#Script execution starts here
get_platform_input;

get_services_input;

get_gpu_input;

#if [[ "${PLATFORM}" != 'openshift' && "${PLATFORM}" != 'azure' ]];
#then
#  silent_installation_input;
#fi

if [ "${PLATFORM}" = 'dockeree' ];
then
  prepare_dockeree_env;
fi

if [ "${PLATFORM}" = 'onebox' ];
then
  source util/onebox-env-setup.sh;
fi

if [ "${PLATFORM}" = "azure" ];
then
  export ONE_INSTALLER_INSTALL=true
  read_azure_input_values;
fi

if [[ "${IS_AIRGAP}" = "y" || "${IS_AIRGAP}" = "Y" ]];
then
  export IS_AIRGAP=true
fi
